<?php
/**
 * Theme Customizer.
 *
 * @package Cosmetro
 */

/**
 * Retrieve a holder for Customizer options.
 *
 * @since  1.0.0
 * @return array
 */

function cosmetro_get_customizer_options() {
	/**
	 * Filter a holder for Customizer options (for theme/plugin developer customization).
	 *
	 * @since 1.0.0
	 */
	return apply_filters( 'cosmetro-theme/customizer/options' , array(
		'prefix'        => 'cosmetro',
		'path'          => get_theme_file_path( 'framework/modules/customizer/' ),
		'capability'    => 'edit_theme_options',
		'type'          => 'theme_mod',
		'fonts_manager' => new CX_Fonts_Manager(),
		'options'       => array(
			
			/** `Site Identity` section */
			'logo_retina' => array(
				'title' 			=> esc_html__( 'Retina Logo', 'cosmetro' ),
				'section' 			=> 'title_tagline',
				'priority' 			=> 8,
				'field' 			=> 'image',
				'type' 				=> 'control',
				'dynamic_css' 		=> true,
			),
			'logo_retina_height' => array(
				'title' 			=> esc_html__( 'Logo Height, px', 'cosmetro' ),
				'section' 			=> 'title_tagline',
				'priority' 			=> 9,
				'default' 			=> 40,
				'field' 			=> 'number',
				'input_attrs' 		=> array(
					'min'  => 20,
					'max'  => 100,
					'step' => 1,
				),
				'type' 				=> 'control',
				'dynamic_css' 		=> true,
			),
			'site_tagline' => array(
				'title' 			=> esc_html__( 'Show Site Tagline', 'cosmetro' ),
				'section' 			=> 'title_tagline',
				'priority' 			=> 10,
				'default' 			=> false,
				'field' 			=> 'checkbox',
				'type' 				=> 'control',
			),

			/** `General` panel */
			'general_settings' => array(
				'title'       => esc_html__( 'General Site settings', 'cosmetro' ),
				'priority'    => 40,
				'type'        => 'panel',
			),

			/** `Favicon` section */
			'favicon' => array(
				'title'       => esc_html__( 'Favicon', 'cosmetro' ),
				'priority'    => 25,
				'panel'       => 'general_settings',
				'type'        => 'section',
			),

			/** `Preloader` section */
			'preloader_section' => array(
				'title'    => esc_html__( 'Page Preloader', 'cosmetro' ),
				'priority' => 30,
				'type'     => 'section',
				'panel'    => 'general_settings',
			),
			'page_preloader' => array(
				'title'    => esc_html__( 'Show page preloader', 'cosmetro' ),
				'section'  => 'preloader_section',
				'priority' => 30,
				'default'  => false,
				'field'    => 'checkbox',
				'type'     => 'control',
			),
			
			/** `Breadcrumbs` section */
			'breadcrumbs' => array(
				'title'    => esc_html__( 'Breadcrumbs', 'cosmetro' ),
				'priority' => 30,
				'type'     => 'section',
				'panel'    => 'general_settings',
			),
			'breadcrumbs_visibillity' => array(
				'title'   => esc_html__( 'Enable Breadcrumbs', 'cosmetro' ),
				'section' => 'breadcrumbs',
				'default' => false,
				'field'   => 'checkbox',
				'type'    => 'control',
			),
			'breadcrumbs_front_visibillity' => array(
				'title'   => esc_html__( 'Enable Breadcrumbs on front page', 'cosmetro' ),
				'section' => 'breadcrumbs',
				'default' => false,
				'field'   => 'checkbox',
				'type'    => 'control',
			),
			'breadcrumbs_path_type' => array(
				'title'   => esc_html__( 'Show full/minified path', 'cosmetro' ),
				'section' => 'breadcrumbs',
				'default' => 'full',
				'field'   => 'select',
				'choices' => array(
					'full'     => esc_html__( 'Full', 'cosmetro' ),
					'minified' => esc_html__( 'Minified', 'cosmetro' ),
				),
				'type'    => 'control',
			),
			'breadcrumbs_text_color' => array(
				'title'       => esc_html__( 'Text Color', 'cosmetro' ),
				'description' => esc_html__( 'Here you can choose whether your text should be light or dark. If you are working with a dark background, then your text should be light. If your background is light, then your text should be set to dark.', 'cosmetro' ),
				'section'     => 'breadcrumbs',
				'default'     => 'dark',
				'field'       => 'select',
				'choices'     => cosmetro_get_text_color(),
				'type'        => 'control',
			),

			/** `Page Layout` section */
			'page_layout' => array(
				'title' 			=> esc_html__( 'Page Layout', 'cosmetro' ),
				'priority' 			=> 55,
				'type' 				=> 'section',
				'panel' 			=> 'general_settings',
			),
			'container_type' => array(
				'title' 			=> esc_html__( 'Container Type', 'cosmetro' ),
				'section' 			=> 'page_layout',
				'default' 			=> 'boxed',
				'field' 			=> 'select',
				'choices' 			=> array(
					'boxed'     => esc_html__( 'Boxed', 'cosmetro' ),
					'fullwidth' => esc_html__( 'Fullwidth', 'cosmetro' ),
				),
				'type' 				=> 'control',
			),
			'container_width' => array(
				'title' 			=> esc_html__( 'Container Width, px', 'cosmetro' ),
				'section' 			=> 'page_layout',
				'default' 			=> 1180,
				'field' 			=> 'number',
				'input_attrs' 		=> array(
					'min'  => 700,
					'max'  => 2000,
					'step' => 1,
				),
				'type' 				=> 'control',
				'dynamic_css' 		=> true,
			),
			'sidebar_width' => array(
				'title' 			=> esc_html__( 'Sidebar width', 'cosmetro' ),
				'section' 			=> 'page_layout',
				'default' 			=> '1/4',
				'field' 			=> 'select',
				'choices' 			=> array(
					'1/3' => '1/3',
					'1/4' => '1/4',
				),
				'sanitize_callback' => 'sanitize_text_field',
				'type' 				=> 'control',
			),

			/* Sticky Sidebar */
			'sticky_sidebar' => array(
				'title' 			=> esc_html__( 'Sticky Sidebar', 'cosmetro' ),
				'section' 			=> 'page_layout',
				'default' 			=> false,
				'field' 			=> 'checkbox',
				'type' 				=> 'control',
			),

			/** `Preloader` section */
			'totop_section' => array(
				'title'    => esc_html__( 'ToTop Button', 'cosmetro' ),
				'priority' => 60,
				'type'     => 'section',
				'panel'    => 'general_settings',
			),
			'totop_visibility' => array(
				'title'   => esc_html__( 'Show ToTop Button', 'cosmetro' ),
				'section' => 'totop_section',
				'priority' => 60,
				'default' => false,
				'field'   => 'checkbox',
				'type'    => 'control',
			),

			/** `Color Scheme` panel */
			'color_scheme' => array(
				'title'       => esc_html__( 'Color Scheme', 'cosmetro' ),
				'description' => esc_html__( 'Configure Color Scheme', 'cosmetro' ),
				'priority'    => 40,
				'type'        => 'section',
			),

			'accent_color' => array(
				'title'   => esc_html__( 'Accent color', 'cosmetro' ),
				'section' => 'color_scheme',
				'default' => '#fe9ec7',
				'field'   => 'hex_color',
				'type'    => 'control',
			),
			'primary_text_color' => array(
				'title' 			=> esc_html__( 'Primary Text color', 'cosmetro' ),
				'section' 			=> 'color_scheme',
				'default' 			=> '#333333',
				'field' 			=> 'hex_color',
				'type' 				=> 'control',
			),
			'secondary_text_color' => array(
				'title' 			=> esc_html__( 'Secondary Text color', 'cosmetro' ),
				'section' 			=> 'color_scheme',
				'default' 			=> '#777777',
				'field' 			=> 'hex_color',
				'type' 				=> 'control',
			),
			'link_color' => array(
				'title' 			=> esc_html__( 'Link color', 'cosmetro' ),
				'section' 			=> 'color_scheme',
				'default' 			=> '#fe9ec7',
				'field' 			=> 'hex_color',
				'type' 				=> 'control',
			),
			'link_hover_color' => array(
				'title' 			=> esc_html__( 'Link hover color', 'cosmetro' ),
				'section' 			=> 'color_scheme',
				'default' 			=> '#333333',
				'field' 			=> 'hex_color',
				'type' 				=> 'control',
			),
			'h1_color' => array(
				'title'   => esc_html__( 'H1 color', 'cosmetro' ),
				'section' => 'color_scheme',
				'default' => '#333333',
				'field'   => 'hex_color',
				'type'    => 'control',
			),
			'h2_color' => array(
				'title'   => esc_html__( 'H2 color', 'cosmetro' ),
				'section' => 'color_scheme',
				'default' => '#333333',
				'field'   => 'hex_color',
				'type'    => 'control',
			),
			'h3_color' => array(
				'title'   => esc_html__( 'H3 color', 'cosmetro' ),
				'section' => 'color_scheme',
				'default' => '#333333',
				'field'   => 'hex_color',
				'type'    => 'control',
			),
			'h4_color' => array(
				'title'   => esc_html__( 'H4 color', 'cosmetro' ),
				'section' => 'color_scheme',
				'default' => '#333333',
				'field'   => 'hex_color',
				'type'    => 'control',
			),
			'h5_color' => array(
				'title'   => esc_html__( 'H5 color', 'cosmetro' ),
				'section' => 'color_scheme',
				'default' => '#333333',
				'field'   => 'hex_color',
				'type'    => 'control',
			),
			'h6_color' => array(
				'title'   => esc_html__( 'H6 color', 'cosmetro' ),
				'section' => 'color_scheme',
				'default' => '#333333',
				'field'   => 'hex_color',
				'type'    => 'control',
			),
			'grey_color_1' => array(
				'title'   => esc_html__( 'Grey color (1)', 'cosmetro' ),
				'section' => 'color_scheme',
				'default' => '#f8f8f8', // new !
				'field'   => 'hex_color',
				'type'    => 'control',
			),
			'invert_text_color' => array(
				'title'   => esc_html__( 'Invert Text color', 'cosmetro' ),
				'section' => 'color_scheme',
				'default' => '#ffffff',
				'field'   => 'hex_color',
				'type'    => 'control',
			),

			'btn_text_color' => array(
				'title'   => esc_html__( 'Button Text Color', 'cosmetro' ),
				'section' => 'color_scheme',
				'default' => '#ffffff',
				'field'   => 'hex_color',
				'type'    => 'control',
			),
			'btn_border_color' => array(
				'title'   => esc_html__( 'Button Border Color', 'cosmetro' ),
				'section' => 'color_scheme',
				'default' => '#333333',
				'field'   => 'hex_color',
				'type'    => 'control',
			),
			'btn_bg_color' => array(
				'title'   => esc_html__( 'Button Background Color', 'cosmetro' ),
				'section' => 'color_scheme',
				'default' => '#333333',
				'field'   => 'hex_color',
				'type'    => 'control',
			),

			/** `Typography Settings` panel */
			'typography' => array(
				'title'       => esc_html__( 'Typography', 'cosmetro' ),
				'description' => esc_html__( 'Configure typography settings', 'cosmetro' ),
				'priority'    => 45,
				'type'        => 'panel',
			),

			/** `Body text` section */
			'body_typography' => array(
				'title'       => esc_html__( 'Body Text', 'cosmetro' ),
				'priority'    => 5,
				'panel'       => 'typography',
				'type'        => 'section',
			),
			'body_font_family' => array(
				'title'   => esc_html__( 'Font Family', 'cosmetro' ),
				'section' => 'body_typography',
				'default' => 'Spartan, sans-serif',
				'field'   => 'fonts',
				'type'    => 'control',
			),
			'body_font_style' => array(
				'title'   => esc_html__( 'Font Style', 'cosmetro' ),
				'section' => 'body_typography',
				'default' => 'normal',
				'field'   => 'select',
				'choices' => cosmetro_get_font_styles(),
				'type'    => 'control',
			),
			'body_font_weight' => array(
				'title'   => esc_html__( 'Font Weight', 'cosmetro' ),
				'section' => 'body_typography',
				'default' => '400',
				'field'   => 'select',
				'choices' => cosmetro_get_font_weight(),
				'type'    => 'control',
			),
			'body_font_size' => array(
				'title'       => esc_html__( 'Font Size, px', 'cosmetro' ),
				'section'     => 'body_typography',
				'default'     => '18',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => 6,
					'max'  => 50,
					'step' => 1,
				),
				'type' => 'control',
			),
			'body_line_height' => array(
				'title'       => esc_html__( 'Line Height', 'cosmetro' ),
				'description' => esc_html__( 'Relative to the font-size of the element', 'cosmetro' ),
				'section'     => 'body_typography',
				'default'     => '1.16',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => 1.0,
					'max'  => 3.0,
					'step' => 0.1,
				),
				'type' => 'control',
			),
			'body_letter_spacing' => array(
				'title'       => esc_html__( 'Letter Spacing, px', 'cosmetro' ),
				'section'     => 'body_typography',
				'default'     => '0',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => -10,
					'max'  => 10,
					'step' => 1,
				),
				'type' => 'control',
			),
			'body_character_set' => array(
				'title'   => esc_html__( 'Character Set', 'cosmetro' ),
				'section' => 'body_typography',
				'default' => 'latin',
				'field'   => 'select',
				'choices' => cosmetro_get_character_sets(),
				'type'    => 'control',
			),
			'body_text_align' => array(
				'title'   => esc_html__( 'Text Align', 'cosmetro' ),
				'section' => 'body_typography',
				'default' => 'left',
				'field'   => 'select',
				'choices' => cosmetro_get_text_aligns(),
				'type'    => 'control',
			),			
			'body_text_transform' => array(
				'title'   => esc_html__( 'Text Transform', 'cosmetro' ),
				'section' => 'body_typography',
				'default' => 'none',
				'field'   => 'select',
				'choices' => cosmetro_get_text_transform(),
				'type'    => 'control',
			),

			/** `H1 Heading` section */
			'h1_typography' => array(
				'title'       => esc_html__( 'H1 Heading', 'cosmetro' ),
				'priority'    => 10,
				'panel'       => 'typography',
				'type'        => 'section',
			),
			'h1_font_family' => array(
				'title'   => esc_html__( 'Font Family', 'cosmetro' ),
				'section' => 'h1_typography',
				'default' => 'Spartan, sans-serif',
				'field'   => 'fonts',
				'type'    => 'control',
			),
			'h1_font_style' => array(
				'title'   => esc_html__( 'Font Style', 'cosmetro' ),
				'section' => 'h1_typography',
				'default' => 'normal',
				'field'   => 'select',
				'choices' => cosmetro_get_font_styles(),
				'type'    => 'control',
			),
			'h1_font_weight' => array(
				'title'   => esc_html__( 'Font Weight', 'cosmetro' ),
				'section' => 'h1_typography',
				'default' => '600',
				'field'   => 'select',
				'choices' => cosmetro_get_font_weight(),
				'type'    => 'control',
			),
			'h1_font_size' => array(
				'title'       => esc_html__( 'Font Size, px', 'cosmetro' ),
				'section'     => 'h1_typography',
				'default'     => '50',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => 10,
					'max'  => 200,
					'step' => 1,
				),
				'type' => 'control',
			),
			'h1_line_height' => array(
				'title'       => esc_html__( 'Line Height', 'cosmetro' ),
				'description' => esc_html__( 'Relative to the font-size of the element', 'cosmetro' ),
				'section'     => 'h1_typography',
				'default'     => '1.32',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => 1.0,
					'max'  => 3.0,
					'step' => 0.1,
				),
				'type' => 'control',
			),
			'h1_letter_spacing' => array(
				'title'       => esc_html__( 'Letter Spacing, px', 'cosmetro' ),
				'section'     => 'h1_typography',
				'default'     => '0',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => -10,
					'max'  => 10,
					'step' => 1,
				),
				'type' => 'control',
			),
			'h1_character_set' => array(
				'title'   => esc_html__( 'Character Set', 'cosmetro' ),
				'section' => 'h1_typography',
				'default' => 'latin',
				'field'   => 'select',
				'choices' => cosmetro_get_character_sets(),
				'type'    => 'control',
			),
			'h1_text_align' => array(
				'title'   => esc_html__( 'Text Align', 'cosmetro' ),
				'section' => 'h1_typography',
				'default' => 'inherit',
				'field'   => 'select',
				'choices' => cosmetro_get_text_aligns(),
				'type'    => 'control',
			),
			'h1_text_transform' => array(
				'title'   => esc_html__( 'Text Transform', 'cosmetro' ),
				'section' => 'h1_typography',
				'default' => 'uppercase',
				'field'   => 'select',
				'choices' => cosmetro_get_text_transform(),
				'type'    => 'control',
			),

			/** `H2 Heading` section */
			'h2_typography' => array(
				'title'       => esc_html__( 'H2 Heading', 'cosmetro' ),
				'priority'    => 15,
				'panel'       => 'typography',
				'type'        => 'section',
			),
			'h2_font_family' => array(
				'title'   => esc_html__( 'Font Family', 'cosmetro' ),
				'section' => 'h2_typography',
				'default' => 'Spartan, sans-serif',
				'field'   => 'fonts',
				'type'    => 'control',
			),
			'h2_font_style' => array(
				'title'   => esc_html__( 'Font Style', 'cosmetro' ),
				'section' => 'h2_typography',
				'default' => 'normal',
				'field'   => 'select',
				'choices' => cosmetro_get_font_styles(),
				'type'    => 'control',
			),
			'h2_font_weight' => array(
				'title'   => esc_html__( 'Font Weight', 'cosmetro' ),
				'section' => 'h2_typography',
				'default' => '600',
				'field'   => 'select',
				'choices' => cosmetro_get_font_weight(),
				'type'    => 'control',
			),
			'h2_font_size' => array(
				'title'       => esc_html__( 'Font Size, px', 'cosmetro' ),
				'section'     => 'h2_typography',
				'default'     => '42',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => 10,
					'max'  => 200,
					'step' => 1,
				),
				'type' => 'control',
			),
			'h2_line_height' => array(
				'title' 			=> esc_html__( 'Line Height', 'cosmetro' ),
				'description' 		=> esc_html__( 'Relative to the font-size of the element', 'cosmetro' ),
				'section' 			=> 'h2_typography',
				'default' 			=> '1.13',
				'field' 			=> 'number',
				'input_attrs' 		=> array(
					'min'  => 1.0,
					'max'  => 3.0,
					'step' => 0.1,
				),
				'type' 				=> 'control',
			),
			'h2_letter_spacing' => array(
				'title'       => esc_html__( 'Letter Spacing, px', 'cosmetro' ),
				'section'     => 'h2_typography',
				'default'     => '0',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => -10,
					'max'  => 10,
					'step' => 1,
				),
				'type' => 'control',
			),
			'h2_character_set' => array(
				'title'   => esc_html__( 'Character Set', 'cosmetro' ),
				'section' => 'h2_typography',
				'default' => 'latin',
				'field'   => 'select',
				'choices' => cosmetro_get_character_sets(),
				'type'    => 'control',
			),
			'h2_text_align' => array(
				'title'   => esc_html__( 'Text Align', 'cosmetro' ),
				'section' => 'h2_typography',
				'default' => 'inherit',
				'field'   => 'select',
				'choices' => cosmetro_get_text_aligns(),
				'type'    => 'control',
			),
			'h2_text_transform' => array(
				'title'   => esc_html__( 'Text Transform', 'cosmetro' ),
				'section' => 'h2_typography',
				'default' => 'uppercase',
				'field'   => 'select',
				'choices' => cosmetro_get_text_transform(),
				'type'    => 'control',
			),

			/** `H3 Heading` section */
			'h3_typography' => array(
				'title'       => esc_html__( 'H3 Heading', 'cosmetro' ),
				'priority'    => 20,
				'panel'       => 'typography',
				'type'        => 'section',
			),
			'h3_font_family' => array(
				'title' 			=> esc_html__( 'Font Family', 'cosmetro' ),
				'section' 			=> 'h3_typography',
				'default' 			=> 'Playfair Display, serif',
				'field' 			=> 'fonts',
				'type' 				=> 'control',
			),
			'h3_font_style' => array(
				'title'   => esc_html__( 'Font Style', 'cosmetro' ),
				'section' => 'h3_typography',
				'default' => 'italic',
				'field'   => 'select',
				'choices' => cosmetro_get_font_styles(),
				'type'    => 'control',
			),
			'h3_font_weight' => array(
				'title'   => esc_html__( 'Font Weight', 'cosmetro' ),
				'section' => 'h3_typography',
				'default' => '400',
				'field'   => 'select',
				'choices' => cosmetro_get_font_weight(),
				'type'    => 'control',
			),
			'h3_font_size' => array(
				'title'       => esc_html__( 'Font Size, px', 'cosmetro' ),
				'section'     => 'h3_typography',
				'default'     => '36',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => 10,
					'max'  => 200,
					'step' => 1,
				),
				'type' => 'control',
			),
			'h3_line_height' => array(
				'title'       => esc_html__( 'Line Height', 'cosmetro' ),
				'description' => esc_html__( 'Relative to the font-size of the element', 'cosmetro' ),
				'section'     => 'h3_typography',
				'default'     => '1.35',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => 1.0,
					'max'  => 3.0,
					'step' => 0.1,
				),
				'type' => 'control',
			),
			'h3_letter_spacing' => array(
				'title'       => esc_html__( 'Letter Spacing, px', 'cosmetro' ),
				'section'     => 'h3_typography',
				'default'     => '0',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => -10,
					'max'  => 10,
					'step' => 1,
				),
				'type' => 'control',
			),
			'h3_character_set' => array(
				'title'   => esc_html__( 'Character Set', 'cosmetro' ),
				'section' => 'h3_typography',
				'default' => 'latin',
				'field'   => 'select',
				'choices' => cosmetro_get_character_sets(),
				'type'    => 'control',
			),
			'h3_text_align' => array(
				'title'   => esc_html__( 'Text Align', 'cosmetro' ),
				'section' => 'h3_typography',
				'default' => 'inherit',
				'field'   => 'select',
				'choices' => cosmetro_get_text_aligns(),
				'type'    => 'control',
			),
			'h3_text_transform' => array(
				'title'   => esc_html__( 'Text Transform', 'cosmetro' ),
				'section' => 'h3_typography',
				'default' => 'uppercase',
				'field'   => 'select',
				'choices' => cosmetro_get_text_transform(),
				'type'    => 'control',
			),

			/** `H4 Heading` section */
			'h4_typography' => array(
				'title'       => esc_html__( 'H4 Heading', 'cosmetro' ),
				'priority'    => 25,
				'panel'       => 'typography',
				'type'        => 'section',
			),
			'h4_font_family' => array(
				'title'   => esc_html__( 'Font Family', 'cosmetro' ),
				'section' => 'h4_typography',
				'default' => 'Spartan, sans-serif',
				'field'   => 'fonts',
				'type'    => 'control',
			),
			'h4_font_style' => array(
				'title'   => esc_html__( 'Font Style', 'cosmetro' ),
				'section' => 'h4_typography',
				'default' => 'normal',
				'field'   => 'select',
				'choices' => cosmetro_get_font_styles(),
				'type'    => 'control',
			),
			'h4_font_weight' => array(
				'title'   => esc_html__( 'Font Weight', 'cosmetro' ),
				'section' => 'h4_typography',
				'default' => '600',
				'field'   => 'select',
				'choices' => cosmetro_get_font_weight(),
				'type'    => 'control',
			),
			'h4_font_size' => array(
				'title'       => esc_html__( 'Font Size, px', 'cosmetro' ),
				'section'     => 'h4_typography',
				'default'     => '24',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => 10,
					'max'  => 200,
					'step' => 1,
				),
				'type' => 'control',
			),
			'h4_line_height' => array(
				'title'       => esc_html__( 'Line Height', 'cosmetro' ),
				'description' => esc_html__( 'Relative to the font-size of the element', 'cosmetro' ),
				'section'     => 'h4_typography',
				'default'     => '1.16',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => 1.0,
					'max'  => 3.0,
					'step' => 0.1,
				),
				'type' => 'control',
			),
			'h4_letter_spacing' => array(
				'title'       => esc_html__( 'Letter Spacing, px', 'cosmetro' ),
				'section'     => 'h4_typography',
				'default'     => '0',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => -10,
					'max'  => 10,
					'step' => 1,
				),
				'type' => 'control',
			),
			'h4_character_set' => array(
				'title'   => esc_html__( 'Character Set', 'cosmetro' ),
				'section' => 'h4_typography',
				'default' => 'latin',
				'field'   => 'select',
				'choices' => cosmetro_get_character_sets(),
				'type'    => 'control',
			),
			'h4_text_align' => array(
				'title'   => esc_html__( 'Text Align', 'cosmetro' ),
				'section' => 'h4_typography',
				'default' => 'inherit',
				'field'   => 'select',
				'choices' => cosmetro_get_text_aligns(),
				'type'    => 'control',
			),
			'h4_text_transform' => array(
				'title'   => esc_html__( 'Text Transform', 'cosmetro' ),
				'section' => 'h4_typography',
				'default' => 'uppercase',
				'field'   => 'select',
				'choices' => cosmetro_get_text_transform(),
				'type'    => 'control',
			),

			/** `H5 Heading` section */
			'h5_typography' => array(
				'title'       => esc_html__( 'H5 Heading', 'cosmetro' ),
				'priority'    => 30,
				'panel'       => 'typography',
				'type'        => 'section',
			),
			'h5_font_family' => array(
				'title'   => esc_html__( 'Font Family', 'cosmetro' ),
				'section' => 'h5_typography',
				'default' => 'Spartan, sans-serif',
				'field'   => 'fonts',
				'type'    => 'control',
			),
			'h5_font_style' => array(
				'title'   => esc_html__( 'Font Style', 'cosmetro' ),
				'section' => 'h5_typography',
				'default' => 'normal',
				'field'   => 'select',
				'choices' => cosmetro_get_font_styles(),
				'type'    => 'control',
			),
			'h5_font_weight' => array(
				'title'   => esc_html__( 'Font Weight', 'cosmetro' ),
				'section' => 'h5_typography',
				'default' => '600',
				'field'   => 'select',
				'choices' => cosmetro_get_font_weight(),
				'type'    => 'control',
			),
			'h5_font_size' => array(
				'title'       => esc_html__( 'Font Size, px', 'cosmetro' ),
				'section'     => 'h5_typography',
				'default'     => '18',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => 10,
					'max'  => 200,
					'step' => 1,
				),
				'type' => 'control',
			),
			'h5_line_height' => array(
				'title'       => esc_html__( 'Line Height', 'cosmetro' ),
				'description' => esc_html__( 'Relative to the font-size of the element', 'cosmetro' ),
				'section'     => 'h5_typography',
				'default'     => '1.16',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => 1.0,
					'max'  => 3.0,
					'step' => 0.1,
				),
				'type' => 'control',
			),
			'h5_letter_spacing' => array(
				'title'       => esc_html__( 'Letter Spacing, px', 'cosmetro' ),
				'section'     => 'h5_typography',
				'default'     => '0',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => -10,
					'max'  => 10,
					'step' => 1,
				),
				'type' => 'control',
			),
			'h5_character_set' => array(
				'title'   => esc_html__( 'Character Set', 'cosmetro' ),
				'section' => 'h5_typography',
				'default' => 'latin',
				'field'   => 'select',
				'choices' => cosmetro_get_character_sets(),
				'type'    => 'control',
			),
			'h5_text_align' => array(
				'title'   => esc_html__( 'Text Align', 'cosmetro' ),
				'section' => 'h5_typography',
				'default' => 'inherit',
				'field'   => 'select',
				'choices' => cosmetro_get_text_aligns(),
				'type'    => 'control',
			),
			'h5_text_transform' => array(
				'title'   => esc_html__( 'Text Transform', 'cosmetro' ),
				'section' => 'h5_typography',
				'default' => 'uppercase',
				'field'   => 'select',
				'choices' => cosmetro_get_text_transform(),
				'type'    => 'control',
			),

			/** `H6 Heading` section */
			'h6_typography' => array(
				'title'       => esc_html__( 'H6 Heading', 'cosmetro' ),
				'priority'    => 35,
				'panel'       => 'typography',
				'type'        => 'section',
			),
			'h6_font_family' => array(
				'title'   => esc_html__( 'Font Family', 'cosmetro' ),
				'section' => 'h6_typography',
				'default' => 'Spartan, sans-serif',
				'field'   => 'fonts',
				'type'    => 'control',
			),
			'h6_font_style' => array(
				'title'   => esc_html__( 'Font Style', 'cosmetro' ),
				'section' => 'h6_typography',
				'default' => 'normal',
				'field'   => 'select',
				'choices' => cosmetro_get_font_styles(),
				'type'    => 'control',
			),
			'h6_font_weight' => array(
				'title'   => esc_html__( 'Font Weight', 'cosmetro' ),
				'section' => 'h6_typography',
				'default' => '600',
				'field'   => 'select',
				'choices' => cosmetro_get_font_weight(),
				'type'    => 'control',
			),
			'h6_font_size' => array(
				'title'       => esc_html__( 'Font Size, px', 'cosmetro' ),
				'section'     => 'h6_typography',
				'default'     => '13',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => 10,
					'max'  => 200,
					'step' => 1,
				),
				'type' => 'control',
			),
			'h6_line_height' => array(
				'title'       => esc_html__( 'Line Height', 'cosmetro' ),
				'description' => esc_html__( 'Relative to the font-size of the element', 'cosmetro' ),
				'section'     => 'h6_typography',
				'default'     => '1.16',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => 1.0,
					'max'  => 3.0,
					'step' => 0.1,
				),
				'type' => 'control',
			),
			'h6_letter_spacing' => array(
				'title'       => esc_html__( 'Letter Spacing, px', 'cosmetro' ),
				'section'     => 'h6_typography',
				'default'     => '0',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => -10,
					'max'  => 10,
					'step' => 1,
				),
				'type' => 'control',
			),
			'h6_character_set' => array(
				'title'   => esc_html__( 'Character Set', 'cosmetro' ),
				'section' => 'h6_typography',
				'default' => 'latin',
				'field'   => 'select',
				'choices' => cosmetro_get_character_sets(),
				'type'    => 'control',
			),
			'h6_text_align' => array(
				'title'   => esc_html__( 'Text Align', 'cosmetro' ),
				'section' => 'h6_typography',
				'default' => 'inherit',
				'field'   => 'select',
				'choices' => cosmetro_get_text_aligns(),
				'type'    => 'control',
			),
			'h6_text_transform' => array(
				'title'   => esc_html__( 'Text Transform', 'cosmetro' ),
				'section' => 'h6_typography',
				'default' => 'uppercase',
				'field'   => 'select',
				'choices' => cosmetro_get_text_transform(),
				'type'    => 'control',
			),

			/** `Logo text` section */
			'logo_typography' => array(
				'title'       => esc_html__( 'Logo Text', 'cosmetro' ),
				'priority'    => 40,
				'panel'       => 'typography',
				'type'        => 'section',
			),
			'header_logo_font_family' => array(
				'title'           => esc_html__( 'Font Family', 'cosmetro' ),
				'section'         => 'logo_typography',
				'default'         => 'Cantata One, serif',
				'field'           => 'fonts',
				'type'            => 'control',
			),
			'header_logo_font_style' => array(
				'title'           => esc_html__( 'Font Style', 'cosmetro' ),
				'section'         => 'logo_typography',
				'default'         => 'normal',
				'field'           => 'select',
				'choices'         => cosmetro_get_font_styles(),
				'type'            => 'control',
			),
			'header_logo_font_weight' => array(
				'title'           => esc_html__( 'Font Weight', 'cosmetro' ),
				'section'         => 'logo_typography',
				'default'         => '400',
				'field'           => 'select',
				'choices'         => cosmetro_get_font_weight(),
				'type'            => 'control',
			),
			'header_logo_font_size' => array(
				'title'           => esc_html__( 'Font Size, px', 'cosmetro' ),
				'section'         => 'logo_typography',
				'default'         => '30',
				'field'           => 'number',
				'input_attrs'     => array(
					'min'  => 6,
					'max'  => 50,
					'step' => 1,
				),
				'type'            => 'control',
			),
			'header_logo_character_set' => array(
				'title'           => esc_html__( 'Character Set', 'cosmetro' ),
				'section'         => 'logo_typography',
				'default'         => 'latin',
				'field'           => 'select',
				'choices'         => cosmetro_get_character_sets(),
				'type'            => 'control',
			),

			/** `Menu` section */
			'menu_typography' => array(
				'title'       => esc_html__( 'Menu', 'cosmetro' ),
				'priority'    => 45,
				'panel'       => 'typography',
				'type'        => 'section',
			),
			'menu_font_family' => array(
				'title'           => esc_html__( 'Font Family', 'cosmetro' ),
				'section'         => 'menu_typography',
				'default'         => 'Spartan, sans-serif',
				'field'           => 'fonts',
				'type'            => 'control',
			),
			'menu_font_style' => array(
				'title'           => esc_html__( 'Font Style', 'cosmetro' ),
				'section'         => 'menu_typography',
				'default'         => 'normal',
				'field'           => 'select',
				'choices'         => cosmetro_get_font_styles(),
				'type'            => 'control',
			),
			'menu_font_weight' => array(
				'title'           => esc_html__( 'Font Weight', 'cosmetro' ),
				'section'         => 'menu_typography',
				'default'         => '600',
				'field'           => 'select',
				'choices'         => cosmetro_get_font_weight(),
				'type'            => 'control',
			),
			'menu_font_size' => array(
				'title'           => esc_html__( 'Font Size, px', 'cosmetro' ),
				'section'         => 'menu_typography',
				'default'         => '11',
				'field'           => 'number',
				'input_attrs'     => array(
					'min'  => 6,
					'max'  => 50,
					'step' => 1,
				),
				'type'            => 'control',
			),
			'menu_line_height' => array(
				'title'       => esc_html__( 'Line Height', 'cosmetro' ),
				'description' => esc_html__( 'Relative to the font-size of the element', 'cosmetro' ),
				'section'     => 'menu_typography',
				'default'     => '1.57',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => 1.0,
					'max'  => 3.0,
					'step' => 0.1,
				),
				'type' => 'control',
			),
			'menu_letter_spacing' => array(
				'title'       => esc_html__( 'Letter Spacing, px', 'cosmetro' ),
				'section'     => 'menu_typography',
				'default'     => '0',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => -10,
					'max'  => 10,
					'step' => 1,
				),
				'type' => 'control',
			),
			'menu_character_set' => array(
				'title' 			=> esc_html__( 'Character Set', 'cosmetro' ),
				'section' 			=> 'menu_typography',
				'default' 			=> 'latin',
				'field' 			=> 'select',
				'choices' 			=> cosmetro_get_character_sets(),
				'type' 				=> 'control',
			),
			'menu_text_transform' => array(
				'title' 			=> esc_html__( 'Text Transform', 'cosmetro' ),
				'section' 			=> 'menu_typography',
				'default' 			=> 'uppercase',
				'field' 			=> 'select',
				'choices' 			=> cosmetro_get_text_transform(),
				'type' 				=> 'control',
			),

			/** `Meta` section */
			'meta_typography' => array(
				'title'       => esc_html__( 'Meta', 'cosmetro' ),
				'priority'    => 50,
				'panel'       => 'typography',
				'type'        => 'section',
			),
			'meta_font_family' => array(
				'title' 			=> esc_html__( 'Font Family', 'cosmetro' ),
				'section' 			=> 'meta_typography',
				'default' 			=> 'Spartan, sans-serif',
				'field' 			=> 'fonts',
				'type' 				=> 'control',
			),
			'meta_font_style' => array(
				'title' 			=> esc_html__( 'Font Style', 'cosmetro' ),
				'section' 			=> 'meta_typography',
				'default' 			=> 'normal',
				'field' 			=> 'select',
				'choices' 			=> cosmetro_get_font_styles(),
				'type' 				=> 'control',
			),
			'meta_font_weight' => array(
				'title' 			=> esc_html__( 'Font Weight', 'cosmetro' ),
				'section' 			=> 'meta_typography',
				'default' 			=> '400',
				'field' 			=> 'select',
				'choices' 			=> cosmetro_get_font_weight(),
				'type' 				=> 'control',
			),
			'meta_font_size' => array(
				'title' 			=> esc_html__( 'Font Size, px', 'cosmetro' ),
				'section' 			=> 'meta_typography',
				'default' 			=> '11',
				'field' 			=> 'number',
				'input_attrs' 		=> array(
					'min'  => 10,
					'max'  => 200,
					'step' => 1,
				),
				'type' 				=> 'control',
			),
			'meta_line_height' => array(
				'title'       => esc_html__( 'Line Height', 'cosmetro' ),
				'description' => esc_html__( 'Relative to the font-size of the element', 'cosmetro' ),
				'section'     => 'meta_typography',
				'default'     => '1.33',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => 1.0,
					'max'  => 3.0,
					'step' => 0.1,
				),
				'type' => 'control',
			),
			'meta_letter_spacing' => array(
				'title'       => esc_html__( 'Letter Spacing, em', 'cosmetro' ),
				'section'     => 'meta_typography',
				'default'     => '0',
				'field'       => 'number',
				'input_attrs' => array(
					'min'  => -1,
					'max'  => 1,
					'step' => 0.01,
				),
				'type' => 'control',
			),
			'meta_character_set' => array(
				'title'   => esc_html__( 'Character Set', 'cosmetro' ),
				'section' => 'meta_typography',
				'default' => 'latin',
				'field'   => 'select',
				'choices' => cosmetro_get_character_sets(),
				'type'    => 'control',
			),
			'meta_text_transform' => array(
				'title'   => esc_html__( 'Text Transform', 'cosmetro' ),
				'section' => 'meta_typography',
				'default' => 'none',
				'field'   => 'select',
				'choices' => cosmetro_get_text_transform(),
				'type'    => 'control',
			),
			
			/** `Button` section */
			'button_typography' => array(
				'title' 			=> esc_html__( 'Button', 'cosmetro' ),
				'priority' 			=> 55,
				'panel' 			=> 'typography',
				'type' 				=> 'section',
			),
			'button_font_family' => array(
				'title' 			=> esc_html__( 'Font Family', 'cosmetro' ),
				'section' 			=> 'button_typography',
				'default' 			=> 'Spartan, sans-serif',
				'field' 			=> 'fonts',
				'type' 				=> 'control',
			),
			'button_font_style' => array(
				'title' 			=> esc_html__( 'Font Style', 'cosmetro' ),
				'section' 			=> 'button_typography',
				'default' 			=> 'normal',
				'field' 			=> 'select',
				'choices' 			=> cosmetro_get_font_styles(),
				'type' 				=> 'control',
			),
			'button_font_weight' => array(
				'title' 			=> esc_html__( 'Font Weight', 'cosmetro' ),
				'section' 			=> 'button_typography',
				'default' 			=> '600',
				'field' 			=> 'select',
				'choices' 			=> cosmetro_get_font_weight(),
				'type' 				=> 'control',
			),
			'button_text_transform' => array(
				'title' 			=> esc_html__( 'Text Transform', 'cosmetro' ),
				'section' 			=> 'button_typography',
				'default' 			=> 'uppercase',
				'field' 			=> 'select',
				'choices' 			=> cosmetro_get_text_transform(),
				'type' 				=> 'control',
			),
			'button_font_size' => array(
				'title' 			=> esc_html__( 'Font Size, px', 'cosmetro' ),
				'section' 			=> 'button_typography',
				'default' 			=> '11',
				'field' 			=> 'number',
				'input_attrs' 		=> array(
					'min'  => 6,
					'max'  => 50,
					'step' => 1,
				),
				'type' 				=> 'control',
			),
			'button_line_height' => array(
				'title' 			=> esc_html__( 'Line Height', 'cosmetro' ),
				'description' 		=> esc_html__( 'Relative to the font-size of the element', 'cosmetro' ),
				'section' 			=> 'button_typography',
				'default' 			=> '1.7',
				'field' 			=> 'number',
				'input_attrs' 		=> array(
					'min'  => 1.0,
					'max'  => 3.0,
					'step' => 0.1,
				),
				'type' 				=> 'control',
			),
			'button_letter_spacing' => array(
				'title' 			=> esc_html__( 'Letter Spacing, px', 'cosmetro' ),
				'section' 			=> 'button_typography',
				'default' 			=> '0',
				'field' 			=> 'number',
				'input_attrs' 		=> array(
					'min'  => -10,
					'max'  => 10,
					'step' => 1,
				),
				'type' 				=> 'control',
			),
			'button_character_set' => array(
				'title' 			=> esc_html__( 'Character Set', 'cosmetro' ),
				'section' 			=> 'button_typography',
				'default' 			=> 'latin',
				'field' 			=> 'select',
				'choices' 			=> cosmetro_get_character_sets(),
				'type' 				=> 'control',
			),

			/** `Header` panel */
			'header_panel' => array(
				'title' 			=> esc_html__( 'Header', 'cosmetro' ),
				'priority' 			=> 105,
				'type' 				=> 'panel',
			),

			'header_styles' => array(
				'title' 			=> esc_html__( 'Style', 'cosmetro' ),
				'panel' 			=> 'header_panel',
				'type' 				=> 'section',
			),
			'header_layout_type' => array(
				'title' 			=> esc_html__( 'Layout', 'cosmetro' ),
				'section' 			=> 'header_styles',
				'default' 			=> 'style-3',
				'choices' 			=> array(
					'style-1' => esc_html__( 'Style 1 (Logo by Center)', 'cosmetro' ),
					'style-2' => esc_html__( 'Style 2 (Hamburger Menu)', 'cosmetro' ),
					'style-3' => esc_html__( 'Style 3 (Logo by Left)', 'cosmetro' ),
				),
				'field' 			=> 'select',
				'type' 				=> 'control',
			),
			'header_container_type' => array(
				'title' 			=> esc_html__( 'Container Type', 'cosmetro' ),
				'section' 			=> 'header_styles',
				'default' 			=> 'boxed',
				'field' 			=> 'select',
				'choices' 			=> array(
					'boxed'     => esc_html__( 'Boxed', 'cosmetro' ),
					'fullwidth' => esc_html__( 'Fullwidth', 'cosmetro' ),
				),
				'type' 				=> 'control',
			),
			'header_social_links' => array(
				'title' 			=> esc_html__( 'Show Social Links', 'cosmetro' ),
				'section' 			=> 'header_styles',
				'default' 			=> false,
				'field' 			=> 'checkbox',
				'type' 				=> 'control',
			),

			'header_search_section' => array(
				'title' 			=> esc_html__( 'Search Popup', 'cosmetro' ),
				'panel' 			=> 'header_panel',
				'type' 				=> 'section',
			),
			'header_search_visible' => array(
				'title' 			=> esc_html__( 'Show Search', 'cosmetro' ),
				'section' 			=> 'header_search_section',
				'default' 			=> true,
				'field' 			=> 'checkbox',
				'type' 				=> 'control',
			),
			'header_search_label' => array(
				'title' 			=> esc_html__( 'Label Text', 'cosmetro' ),
				'section' 			=> 'header_search_section',
				'default' 			=> esc_html__( 'What are you looking for?', 'cosmetro' ),
				'field' 			=> 'text',
				'type' 				=> 'control',
				'conditions' 		=> array(
					'header_search_visible' 	=> true,
				),
			),
			'header_search_placeholder' => array(
				'title' 			=> esc_html__( 'Placeholder Text', 'cosmetro' ),
				'section' 			=> 'header_search_section',
				'default' 			=> esc_html__( 'Enter keyword...', 'cosmetro' ),
				'field' 			=> 'text',
				'type' 				=> 'control',
				'conditions' 		=> array(
					'header_search_visible' 	=> true,
				),
			),

			/** `Footer` panel */
			'footer_options' => array(
				'title' 			=> esc_html__( 'Footer', 'cosmetro' ),
				'priority' 			=> 110,
				'type' 				=> 'section',
			),
			'footer_bg' => array(
				'title' 			=> esc_html__( 'Background Color', 'cosmetro' ),
				'section' 			=> 'footer_options',
				'default' 			=> '#333333',
				'field' 			=> 'hex_color',
				'type' 				=> 'control',
				'dynamic_css' 		=> true,
			),
			'footer_text_color' => array(
				'title' 			=> esc_html__( 'Text Color', 'cosmetro' ),
				'section' 			=> 'footer_options',
				'default' 			=> '#777777',
				'field' 			=> 'hex_color',
				'type' 				=> 'control',
				'dynamic_css' 		=> true,
			),
			'footer_copyright' => array(
				'title' 			=> esc_html__( 'Copyright text', 'cosmetro' ),
				'section' 			=> 'footer_options',
				'default' 			=> cosmetro_get_default_footer_copyright(),
				'field' 			=> 'textarea',
				'type' 				=> 'control',
			),
			'footer_logo' => array(
				'title' 			=> esc_html__( 'Footer Logo', 'cosmetro' ),
				'section' 			=> 'footer_options',
				'field' 			=> 'image',
				'type' 				=> 'control',
				'dynamic_css' 		=> true,
			),

			/** `Blog Settings` panel */
			'blog_settings' => array(
				'title' 			=> esc_html__( 'Blog Settings', 'cosmetro' ),
				'priority' 			=> 115,
				'type' 				=> 'panel',
			),

			/** `Blog` section */
			'blog' => array(
				'title' 			=> esc_html__( 'Blog', 'cosmetro' ),
				'panel' 			=> 'blog_settings',
				'priority' 			=> 10,
				'type' 				=> 'section',
			),

			/* Blog Page Title */
			'blog_page_title' => array(
				'title' 			=> esc_html__( 'Show Blog Page Title', 'cosmetro' ),
				'section' 			=> 'blog',
				'default' 			=> true,
				'field' 			=> 'checkbox',
				'type' 				=> 'control',
			),
			'blog_page_subtitle' => array(
				'title' 			=> esc_html__( 'Blog Page Subtitle', 'cosmetro' ),
				'section' 			=> 'blog',
				'default' 			=> '',
				'field' 			=> 'textarea',
				'type' 				=> 'control',
				'conditions' 		=> array(
					'blog_page_title' => true,
				),
			),

			'blog_layout_columns' => array(
				'title' 			=> esc_html__( 'Columns', 'cosmetro' ),
				'section' 			=> 'blog',
				'default'			=> '2-cols',
				'field' 			=> 'select',
				'choices' 			=> array(
					'2-cols' => esc_html__( '2 columns', 'cosmetro' ),
					'3-cols' => esc_html__( '3 columns', 'cosmetro' ),
				),
				'type' 				=> 'control',
				'active_callback' 	=> 'cosmetro_is_blog_columns_enabled',
			),
			'blog_sidebar_position' => array(
				'title' 			=> esc_html__( 'Sidebar', 'cosmetro' ),
				'section' 			=> 'blog',
				'default' 			=> 'one-right-sidebar',
				'field' 			=> 'select',
				'choices' 			=> array(
					'one-left-sidebar' 	=> esc_html__( 'Sidebar on left side', 'cosmetro' ),
					'one-right-sidebar' => esc_html__( 'Sidebar on right side', 'cosmetro' ),
					'none' 				=> esc_html__( 'No sidebar', 'cosmetro' ),
				),
				'type' 				=> 'control',
				'active_callback' 	=> 'cosmetro_is_blog_sidebar_enabled',
			),
			'blog_sticky_type' => array(
				'title' 			=> esc_html__( 'Sticky label type', 'cosmetro' ),
				'section' 			=> 'blog',
				'default' 			=> 'icon',
				'field' 			=> 'select',
				'choices' 			=> array(
					'label' => esc_html__( 'Text Label', 'cosmetro' ),
					'icon'  => esc_html__( 'Font Icon', 'cosmetro' ),
					'both'  => esc_html__( 'Text with Icon', 'cosmetro' ),
				),
				'type' 				=> 'control',
			),
			'blog_sticky_label' => array(
				'description' 		=> esc_html__( 'Label for sticky post', 'cosmetro' ),
				'section' 			=> 'blog',
				'default' 			=> esc_html__( 'Featured', 'cosmetro' ),
				'field' 			=> 'text',
				'type' 				=> 'control',
				'conditions' 		=> array(
					'blog_sticky_type' => array( 'label', 'both' ),
				),
			),
			'blog_post_author' => array(
				'title' 			=> esc_html__( 'Show post author', 'cosmetro' ),
				'section' 			=> 'blog',
				'default' 			=> true,
				'field' 			=> 'checkbox',
				'type' 				=> 'control',
			),
			'blog_post_publish_date' => array(
				'title' 			=> esc_html__( 'Show publish date', 'cosmetro' ),
				'section' 			=> 'blog',
				'default' 			=> true,
				'field' 			=> 'checkbox',
				'type' 				=> 'control',
			),
			'blog_post_categories' => array(
				'title' 			=> esc_html__( 'Show categories', 'cosmetro' ),
				'section' 			=> 'blog',
				'default' 			=> true,
				'field' 			=> 'checkbox',
				'type' 				=> 'control',
			),
			'blog_post_tags' => array(
				'title' 			=> esc_html__( 'Show tags', 'cosmetro' ),
				'section' 			=> 'blog',
				'default' 			=> false,
				'field' 			=> 'checkbox',
				'type' 				=> 'control',
			),
			'blog_post_comments' => array(
				'title' 			=> esc_html__( 'Show comments', 'cosmetro' ),
				'section' 			=> 'blog',
				'default' 			=> true,
				'field' 			=> 'checkbox',
				'type' 				=> 'control',
			),
			'blog_post_excerpt' => array(
				'title' 			=> esc_html__( 'Show Excerpt', 'cosmetro' ),
				'section' 			=> 'blog',
				'default' 			=> true,
				'field' 			=> 'checkbox',
				'type' 				=> 'control'
			),
			'blog_post_excerpt_words_count' => array(
				'title' 			=> esc_html__( 'Excerpt Words Count', 'cosmetro' ),
				'section' 			=> 'blog',
				'default' 			=> '25',
				'field' 			=> 'number',
				'input_attrs' 		=> array(
					'min'  => 1,
					'max'  => 100,
					'step' => 1,
				),
				'type' 				=> 'control',
			),
			'blog_read_more_type' => array(
				'title' 			=> esc_html__( 'Read more button type', 'cosmetro' ),
				'section' 			=> 'blog',
				'default' 			=> true,
				'field' 			=> 'checkbox',
				'type' 				=> 'control',
			),
			'blog_read_more_text' => array(
				'title' 			=> esc_html__( 'Read more button text', 'cosmetro' ),
				'section' 			=> 'blog',
				'default' 			=> esc_html__( 'Learn more', 'cosmetro' ),
				'field' 			=> 'text',
				'type' 				=> 'control',
				'conditions' 		=> array(
					'blog_read_more_type' => true,
				)
			),

			/** `Post` section */
			'blog_post' => array(
				'title'           => esc_html__( 'Post', 'cosmetro' ),
				'panel'           => 'blog_settings',
				'priority'        => 20,
				'type'            => 'section',
				'active_callback' => 'callback_single',
			),
			'single_sidebar_position' => array(
				'title'   => esc_html__( 'Sidebar', 'cosmetro' ),
				'section' => 'blog_post',
				'default' => 'one-right-sidebar',
				'field'   => 'select',
				'choices' => array(
					'one-left-sidebar'  => esc_html__( 'Sidebar on left side', 'cosmetro' ),
					'one-right-sidebar' => esc_html__( 'Sidebar on right side', 'cosmetro' ),
					'none'              => esc_html__( 'No sidebar', 'cosmetro' ),
				),
				'type' => 'control',
			),
			'single_post_author' => array(
				'title'   => esc_html__( 'Show post author', 'cosmetro' ),
				'section' => 'blog_post',
				'default' => true,
				'field'   => 'checkbox',
				'type'    => 'control',
			),
			'single_post_publish_date' => array(
				'title'   => esc_html__( 'Show publish date', 'cosmetro' ),
				'section' => 'blog_post',
				'default' => true,
				'field'   => 'checkbox',
				'type'    => 'control',
			),
			'single_post_comments' => array(
				'title'   => esc_html__( 'Show comments', 'cosmetro' ),
				'section' => 'blog_post',
				'default' => true,
				'field'   => 'checkbox',
				'type'    => 'control',
			),
			'single_post_categories' => array(
				'title'   => esc_html__( 'Show categories', 'cosmetro' ),
				'section' => 'blog_post',
				'default' => true,
				'field'   => 'checkbox',
				'type'    => 'control',
			),
			'single_post_tags' => array(
				'title'   => esc_html__( 'Show tags', 'cosmetro' ),
				'section' => 'blog_post',
				'default' => true,
				'field'   => 'checkbox',
				'type'    => 'control',
			),
			'single_post_navigation' => array(
				'title'   => esc_html__( 'Enable post navigation', 'cosmetro' ),
				'section' => 'blog_post',
				'default' => true,
				'field'   => 'checkbox',
				'type'    => 'control',
			),

			/** `Author Bio` section */
			'post_authorbio' => array(
				'title' 			=> esc_html__( 'Author Bio Block', 'cosmetro' ),
				'panel' 			=> 'blog_settings',
				'priority' 			=> 25,
				'type' 				=> 'section',
				'active_callback' 	=> 'callback_single',
			),
			'post_authorbio_block' => array(
				'title' 			=> esc_html__( 'Show Author Bio Block', 'cosmetro' ),
				'section' 			=> 'post_authorbio',
				'default' 			=> true,
				'field' 			=> 'checkbox',
				'type' 				=> 'control',
			),
			'post_authorbio_bg' => array(
				'title' 			=> esc_html__( 'Author Bio BG Color', 'cosmetro' ),
				'section' 			=> 'post_authorbio',
				'default' 			=> '#333333',
				'field' 			=> 'hex_color',
				'type' 				=> 'control',
				'conditions' 		=> array(
					'post_authorbio_block' => true,
				),
			),
			'post_authorbio_color' => array(
				'title' 			=> esc_html__( 'Author Bio Text Color', 'cosmetro' ),
				'section' 			=> 'post_authorbio',
				'default' 			=> '#ffffff',
				'field' 			=> 'hex_color',
				'type' 				=> 'control',
				'conditions' 		=> array(
					'post_authorbio_block' => true,
				),
			),

			/** `Related Posts` section */
			'related_posts' => array(
				'title' 			=> esc_html__( 'Related Posts Block', 'cosmetro' ),
				'panel' 			=> 'blog_settings',
				'priority' 			=> 30,
				'type' 				=> 'section',
				'active_callback' 	=> 'callback_single',
			),
			'related_posts_visible' => array(
				'title' 			=> esc_html__( 'Show related posts block', 'cosmetro' ),
				'section' 			=> 'related_posts',
				'default' 			=> true,
				'field' 			=> 'checkbox',
				'type' 				=> 'control',
			),
			'related_posts_block_title' => array(
				'title' 			=> esc_html__( 'Related posts block title', 'cosmetro' ),
				'section' 			=> 'related_posts',
				'default' 			=> esc_html__( 'Related Posts', 'cosmetro' ),
				'field' 			=> 'text',
				'type' 				=> 'control',
				'conditions' 		=> array(
					'related_posts_visible' => true,
				),
			),
			'related_posts_count' => array(
				'title' 			=> esc_html__( 'Number of post', 'cosmetro' ),
				'section' 			=> 'related_posts',
				'default' 			=> '2',
				'field' 			=> 'text',
				'type' 				=> 'control',
				'conditions' 		=> array(
					'related_posts_visible' => true,
				),
			),
			'related_posts_grid' => array(
				'title' 			=> esc_html__( 'Layout', 'cosmetro' ),
				'section' 			=> 'related_posts',
				'default' 			=> '2',
				'field' 			=> 'select',
				'choices' 			=> array(
					'2' 	=> esc_html__( '2 columns', 'cosmetro' ),
					'3' 	=> esc_html__( '3 columns', 'cosmetro' ),
				),
				'type' 				=> 'control',
				'conditions' 		=> array(
					'related_posts_visible' => true,
				),
			),

			'related_posts_image' => array(
				'title' 			=> esc_html__( 'Show post image', 'cosmetro' ),
				'section' 			=> 'related_posts',
				'default' 			=> true,
				'field' 			=> 'checkbox',
				'type' 				=> 'control',
				'conditions' 		=> array(
					'related_posts_visible' => true,
				),
			),
			'related_posts_categories' => array(
				'title' 			=> esc_html__( 'Show post categories', 'cosmetro' ),
				'section' 			=> 'related_posts',
				'default' 			=> true,
				'field' 			=> 'checkbox',
				'type' 				=> 'control',
				'conditions' 		=> array(
					'related_posts_visible' => true,
				),
			),
			'related_posts_title' => array(
				'title' 			=> esc_html__( 'Show post title', 'cosmetro' ),
				'section' 			=> 'related_posts',
				'default' 			=> true,
				'field' 			=> 'checkbox',
				'type' 				=> 'control',
				'conditions' 		=> array(
					'related_posts_visible' => true,
				),
			),
			'related_posts_excerpt' => array(
				'title' 			=> esc_html__( 'Display excerpt', 'cosmetro' ),
				'section' 			=> 'related_posts',
				'default' 			=> true,
				'field' 			=> 'checkbox',
				'type' 				=> 'control',
				'conditions' 		=> array(
					'related_posts_visible' => true,
				),
			),
			'related_posts_excerpt_words_count' => array(
				'title' 			=> esc_html__( 'Excerpt Words Count', 'cosmetro' ),
				'section' 			=> 'related_posts',
				'default' 			=> '15',
				'field' 			=> 'number',
				'input_attrs' 		=> array(
					'min'  => 1,
					'max'  => 100,
					'step' => 1,
				),
				'type' 				=> 'control',
				'conditions' 		=> array(
					'related_posts_visible' => true,
					'related_posts_excerpt' => true,
				),
			),
			'related_posts_author' => array(
				'title' 			=> esc_html__( 'Show post author', 'cosmetro' ),
				'section' 			=> 'related_posts',
				'default' 			=> false,
				'field' 			=> 'checkbox',
				'type' 				=> 'control',
				'conditions' 		=> array(
					'related_posts_visible' => true,
				),
			),
			'related_posts_publish_date' => array(
				'title' 			=> esc_html__( 'Show post publish date', 'cosmetro' ),
				'section' 			=> 'related_posts',
				'default' 			=> true,
				'field' 			=> 'checkbox',
				'type' 				=> 'control',
				'conditions' 		=> array(
					'related_posts_visible' => true,
				),
			),
			'related_posts_comment_count' => array(
				'title' 			=> esc_html__( 'Show post comment count', 'cosmetro' ),
				'section' 			=> 'related_posts',
				'default' 			=> false,
				'field' 			=> 'checkbox',
				'type' 				=> 'control',
				'conditions' 		=> array(
					'related_posts_visible' => true,
				),
			),			
			'related_posts_tags' => array(
				'title' 			=> esc_html__( 'Show post tags', 'cosmetro' ),
				'section' 			=> 'related_posts',
				'default' 			=> false,
				'field' 			=> 'checkbox',
				'type' 				=> 'control',
				'conditions' 		=> array(
					'related_posts_visible' => true,
				),
			),
			'related_posts_learn_more' => array(
				'title' 			=> esc_html__( 'Show Learn More', 'cosmetro' ),
				'section' 			=> 'related_posts',
				'default' 			=> true,
				'field' 			=> 'checkbox',
				'type' 				=> 'control',
				'conditions' 		=> array(
					'related_posts_visible' => true,
				),
			),
	) ) );
}

/**
 * Return true if value of passed setting is not equal with passed value.
 *
 * @param  object $control Parent control.
 * @param  string $setting Setting name to check.
 * @param  string $value   Setting value to compare.
 * @return bool
 */
function cosmetro_is_not_setting( $control, $setting, $value ) {

	if ( $value !== $control->manager->get_setting( $setting )->value() ) {
		return true;
	}

	return false;

}

/**
 * Move native `site_icon` control (based on WordPress core) into custom section.
 *
 * @since 1.0.0
 * @param  object $wp_customize
 * @return void
 */
function cosmetro_customizer_change_core_controls( $wp_customize ) {
	$wp_customize->get_control( 'site_icon' )->section      = 'cosmetro_favicon';
	$wp_customize->get_control( 'background_color' )->label = esc_html__( 'Body Background Color', 'cosmetro' );
}

// Move native `site_icon` control (based on WordPress core) in custom section.
add_action( 'customize_register', 'cosmetro_customizer_change_core_controls', 20 );

/**
 * Get font styles
 *
 * @since 1.0.0
 * @return array
 */
function cosmetro_get_font_styles() {
	return apply_filters( 'cosmetro-theme/font/styles', array(
		'normal'  => esc_html__( 'Normal', 'cosmetro' ),
		'italic'  => esc_html__( 'Italic', 'cosmetro' ),
		'oblique' => esc_html__( 'Oblique', 'cosmetro' ),
		'inherit' => esc_html__( 'Inherit', 'cosmetro' ),
	) );
}

/**
 * Get character sets
 *
 * @since 1.0.0
 * @return array
 */
function cosmetro_get_character_sets() {
	return apply_filters( 'cosmetro-theme/font/character_sets', array(
		'latin'        => esc_html__( 'Latin', 'cosmetro' ),
		'greek'        => esc_html__( 'Greek', 'cosmetro' ),
		'greek-ext'    => esc_html__( 'Greek Extended', 'cosmetro' ),
		'vietnamese'   => esc_html__( 'Vietnamese', 'cosmetro' ),
		'cyrillic-ext' => esc_html__( 'Cyrillic Extended', 'cosmetro' ),
		'latin-ext'    => esc_html__( 'Latin Extended', 'cosmetro' ),
		'cyrillic'     => esc_html__( 'Cyrillic', 'cosmetro' ),
	) );
}

/**
 * Get text aligns
 *
 * @since 1.0.0
 * @return array
 */
function cosmetro_get_text_aligns() {
	return apply_filters( 'cosmetro-theme/font/text-aligns', array(
		'inherit' => esc_html__( 'Inherit', 'cosmetro' ),
		'center'  => esc_html__( 'Center', 'cosmetro' ),
		'justify' => esc_html__( 'Justify', 'cosmetro' ),
		'left'    => esc_html__( 'Left', 'cosmetro' ),
		'right'   => esc_html__( 'Right', 'cosmetro' ),
	) );
}

/**
 * Get font weights
 *
 * @since 1.0.0
 * @return array
 */
function cosmetro_get_font_weight() {
	return apply_filters( 'cosmetro-theme/font/weight', array(
		'100' => '100',
		'200' => '200',
		'300' => '300',
		'400' => '400',
		'500' => '500',
		'600' => '600',
		'700' => '700',
		'800' => '800',
		'900' => '900',
	) );
}

/**
 * Get text transform.
 *
 * @since 1.0.0
 * @return array
 */
function cosmetro_get_text_transform() {
	return apply_filters( 'cosmetro_get_text_transform', array(
		'none'       => esc_html__( 'None ', 'cosmetro' ),
		'uppercase'  => esc_html__( 'Uppercase ', 'cosmetro' ),
		'lowercase'  => esc_html__( 'Lowercase', 'cosmetro' ),
		'capitalize' => esc_html__( 'Capitalize', 'cosmetro' ),
	) );
}

// Background utility function
/**
 * Get background position
 *
 * @since 1.0.0
 * @return array
 */
function cosmetro_get_bg_position() {
	return apply_filters( 'cosmetro_get_bg_position', array(
		'top-left'      => esc_html__( 'Top Left', 'cosmetro' ),
		'top-center'    => esc_html__( 'Top Center', 'cosmetro' ),
		'top-right'     => esc_html__( 'Top Right', 'cosmetro' ),
		'center-left'   => esc_html__( 'Middle Left', 'cosmetro' ),
		'center'        => esc_html__( 'Middle Center', 'cosmetro' ),
		'center-right'  => esc_html__( 'Middle Right', 'cosmetro' ),
		'bottom-left'   => esc_html__( 'Bottom Left', 'cosmetro' ),
		'bottom-center' => esc_html__( 'Bottom Center', 'cosmetro' ),
		'bottom-right'  => esc_html__( 'Bottom Right', 'cosmetro' ),
	) );
}

/**
 * Get background size
 *
 * @since 1.0.0
 * @return array
 */
function cosmetro_get_bg_size() {
	return apply_filters( 'cosmetro_get_bg_size', array(
		'auto'    => esc_html__( 'Auto', 'cosmetro' ),
		'cover'   => esc_html__( 'Cover', 'cosmetro' ),
		'contain' => esc_html__( 'Contain', 'cosmetro' ),
	) );
}

/**
 * Get background repeat
 *
 * @since 1.0.0
 * @return array
 */
function cosmetro_get_bg_repeat() {
	return apply_filters( 'cosmetro_get_bg_repeat', array(
		'no-repeat' => esc_html__( 'No Repeat', 'cosmetro' ),
		'repeat'    => esc_html__( 'Tile', 'cosmetro' ),
		'repeat-x'  => esc_html__( 'Tile Horizontally', 'cosmetro' ),
		'repeat-y'  => esc_html__( 'Tile Vertically', 'cosmetro' ),
	) );
}

/**
 * Get background attachment
 *
 * @since 1.0.0
 * @return array
 */
function cosmetro_get_bg_attachment() {
	return apply_filters( 'cosmetro_get_bg_attachment', array(
		'scroll' => esc_html__( 'Scroll', 'cosmetro' ),
		'fixed'  => esc_html__( 'Fixed', 'cosmetro' ),
	) );
}

/**
 * Get text color
 *
 * @since 1.0.0
 * @return array
 */
function cosmetro_get_text_color() {
	return apply_filters( 'cosmetro_get_text_color', array(
		'light' => esc_html__( 'Light', 'cosmetro' ),
		'dark'  => esc_html__( 'Dark', 'cosmetro' ),
	) );
}


/**
 * Return array of arguments for dynamic CSS module
 *
 * @return array
 */

function cosmetro_get_dynamic_css_options() {
	return apply_filters( 'cosmetro-theme/dynamic_css/options', array(
		'prefix'        => 'cosmetro',
		'type'          => 'theme_mod',
		'parent_handles' => array(
			'css' => 'cosmetro-theme-style',
			'js'  => 'cosmetro-theme-js',
		),
		'css_files'      => array(
			get_theme_file_path( 'assets/css/dynamic.css' ),
			get_theme_file_path( 'assets/css/dynamic/header.css' ),
			get_theme_file_path( 'assets/css/dynamic/footer.css' ),
			get_theme_file_path( 'assets/css/dynamic/menus.css' ),
			get_theme_file_path( 'assets/css/dynamic/social.css' ),
			get_theme_file_path( 'assets/css/dynamic/navigation.css' ),
			get_theme_file_path( 'assets/css/dynamic/buttons.css' ),
			get_theme_file_path( 'assets/css/dynamic/forms.css' ),
			get_theme_file_path( 'assets/css/dynamic/post.css' ),
			get_theme_file_path( 'assets/css/dynamic/page.css' ),
			get_theme_file_path( 'assets/css/dynamic/post-grid.css' ),
			get_theme_file_path( 'assets/css/dynamic/widgets.css' ),
			get_theme_file_path( 'assets/css/dynamic/plugins.css' ),
		),
		'options_cb'     => 'get_theme_mods',
	) );
}

/**
 * Return true if setting is value. Otherwise - return false.
 *
 * @param  object $control Parent control.
 * @param  string $setting Setting name to check.
 * @param  string $value   Setting value to compare.
 * @return bool
 */
function cosmetro_is_setting( $control, $setting, $value ) {

	if ( $value == $control->manager->get_setting( $setting )->value() ) {
		return true;
	}

	return false;
}

/**
 * Get default footer copyright.
 *
 * @since  1.0.0
 * @return string
 */
function cosmetro_get_default_footer_copyright() {
	return esc_html__( '%%site-name%% Theme is proudly powered by WordPress Entries (RSS) and Comments (RSS) © %%privacy-policy%%.', 'cosmetro' );
}

/**
 * Return true if blog sidebar enabled.
 *
 * @return bool
 */
function cosmetro_is_blog_sidebar_enabled() {
	return apply_filters( 'cosmetro-theme/customizer/blog-sidebar-enabled', true );
}

/**
 * Return true if blog columns enabled.
 *
 * @return bool
 */
function cosmetro_is_blog_columns_enabled() {
	return apply_filters( 'cosmetro-theme/customizer/blog-columns-enabled', true );
}

/**
 * Load dynamic logic for the customizer controls area.
 *
 * @since 1.0.0
 */
function cosmetro_customize_controls_assets() {
	wp_enqueue_script( 'cosmetro-theme-customizer-controls', get_theme_file_uri('assets/js/customizer-controls.js' ), array( 'customize-controls' ), cosmetro_theme()->version, true );

	wp_localize_script( 'cosmetro-theme-customizer-controls', 'cosmetroControlsConditions', cosmetro_get_customize_controls_conditions() );
}

add_action( 'customize_controls_enqueue_scripts', 'cosmetro_customize_controls_assets' );

/**
 * Get customize controls conditions.
 *
 * @since  1.0.0
 * @return array
 */
function cosmetro_get_customize_controls_conditions() {

	$customize_options = cosmetro_get_customizer_options();
	$controls_args     = $customize_options['options'];

	$results = array();

	foreach ( $controls_args as $control => $args ) {
		if ( isset( $args['conditions'] ) ) {
			$results[ $control ] = $args['conditions'];
		}
	}

	return $results;
}